<?php

namespace Litecms\Notice\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Litecms\Notice\Forms\Notice as NoticeForm;
use Litecms\Notice\Http\Requests\NoticeResourceRequest;
use Litecms\Notice\Http\Resources\NoticeResource;
use Litecms\Notice\Http\Resources\NoticesCollection;
use Litecms\Notice\Models\Notice;
use Litecms\Notice\Actions\NoticeAction;
use Litecms\Notice\Actions\NoticeActions;


/**
 * Resource controller class for notice.
 */
class NoticeResourceController extends BaseController
{

    /**
     * Initialize notice resource controller.
     *
     *
     * @return null
     */
    public function __construct()
    {
        parent::__construct();
        $this->form = NoticeForm::grouped(false)
                        ->setAttributes()
                        ->toArray();
        $this->modules = $this->modules(config('litecms.notice.modules'), 'notice', guard_url('notice'));
    }

    /**
     * Display a list of notice.
     *
     * @return Response
     */
    public function index(NoticeResourceRequest $request)
    {
        $request = $request->all();
        $page = NoticeActions::run('paginate', $request);

        $data = new NoticesCollection($page);

        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('notice::notice.names'))
            ->view('notice::notice.index')
            ->data(compact('data', 'modules', 'form'))
            ->output();

    }

    /**
     * Display notice.
     *
     * @param Request $request
     * @param Model   $notice
     *
     * @return Response
     */
    public function show(NoticeResourceRequest $request, Notice $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new NoticeResource($model);
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('notice::notice.name'))
            ->data(compact('data', 'form', 'modules'))
            ->view('notice::notice.show')
            ->output();
    }

    /**
     * Show the form for creating a new notice.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(NoticeResourceRequest $request, Notice $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new NoticeResource($model);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('notice::notice.name'))
            ->view('notice::notice.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Create new notice.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(NoticeResourceRequest $request, Notice $model)
    {
        try {
            $request = $request->all();
            $model = NoticeAction::run('store', $model, $request);
            $data = new NoticeResource($model);
            return $this->response->message(trans('messages.success.created', ['Module' => trans('notice::notice.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('notice/notice/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/notice/notice'))
                ->redirect();
        }

    }

    /**
     * Show notice for editing.
     *
     * @param Request $request
     * @param Model   $notice
     *
     * @return Response
     */
    public function edit(NoticeResourceRequest $request, Notice $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new NoticeResource($model);
        // return view('notice::notice.edit', compact('data', 'form', 'modules'));

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('notice::notice.name'))
            ->view('notice::notice.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Update the notice.
     *
     * @param Request $request
     * @param Model   $notice
     *
     * @return Response
     */
    public function update(NoticeResourceRequest $request, Notice $model)
    {
        try {
            $request = $request->all();
            $model = NoticeAction::run('update', $model, $request);
            $data = new NoticeResource($model);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('notice::notice.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('notice/notice/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('notice/notice/' .  $model->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the notice.
     *
     * @param Model   $notice
     *
     * @return Response
     */
    public function destroy(NoticeResourceRequest $request, Notice $model)
    {
        try {

            $request = $request->all();
            $model = NoticeAction::run('destroy', $model, $request);
            $data = new NoticeResource($model);

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('notice::notice.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('notice/notice/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('notice/notice/' .  $model->getRouteKey()))
                ->redirect();
        }

    }
}
